#
# spec file for package perl-Search-Xapian
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Search-Xapian
Name:           perl-Search-Xapian
Version:        1.2.25.5
Release:        bp155.1.5
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl XS frontend to the Xapian C++ search library
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/O/OL/OLLY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Devel::Leak)
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  libxapian-devel
# MANUAL END

%description
This module wraps most methods of most Xapian classes. The missing classes
and methods should be added in the future. It also provides a simplified,
more 'perlish' interface to some common operations, as demonstrated above.

There are some gaps in the POD documentation for wrapped classes, but you
can read the Xapian C++ API documentation at
https://xapian.org/docs/apidoc/html/annotated.html for details of these.
Alternatively, take a look at the code in the examples and tests.

If you want to use Search::Xapian and the threads module together, make
sure you're using Search::Xapian >= 1.0.4.0 and Perl >= 5.8.7. As of
1.0.4.0, Search::Xapian uses CLONE_SKIP to make sure that the perl wrapper
objects aren't copied to new threads - without this the underlying C++
objects can get destroyed more than once.

If you encounter problems, or have any comments, suggestions, patches, etc
please email the Xapian-discuss mailing list (details of which can be found
at https://xapian.org/lists).

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README

%changelog
* Mon Feb 28 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.2.25.5
  see /usr/share/doc/packages/perl-Search-Xapian/Changes
  1.2.25.5  Sun Feb 27 23:46:46 UTC 2022
  [Changes contributed by Olly Betts]
  - The exception fix in 1.2.25.3 unintentionally broke the build with
  xapian-core < 1.4.10.  To fix this we now generate the exception
  handling code at build time, and enable the new exceptions based on
  the version of xapian-core we're building against.
* Fri Nov 20 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.2.25.4
  see /usr/share/doc/packages/perl-Search-Xapian/Changes
  1.2.25.4  Thu Nov 19 23:37:21 UTC 2020
  [Changes contributed by Olly Betts]
  - Add exception-related files which were new in 1.2.25.3 to MANIFEST
  so they're shipped.  Reported by Tina Müller and Leah Neukirchen.
  - Add metadata links to homepage, bugtracker and VCS.  Suggested by
  Gabor Szabo.
  1.2.25.3  Tue Nov 17 00:33:44 UTC 2020
  [Changes contributed by Alyssa Ross]
  - Allow AUTOMATED_TESTING builds against xapian-core 1.4.x.
  [Changes contributed by Olly Betts]
  - Properly handle newer exceptions.  The C++ exception class
  WildcardError wasn't known to the Perl bindings, and would result in
  croak("something terrible happened").  The C++ exception classes
  DatabaseClosedError and DatabaseNotFoundError also weren't known, but
  these would instead be reported as their base classes DatabaseError
  and DatabaseOpeningError respectively.  Reported by Adam Sjøgren.
  - README: Update to reflect that the SWIG-generated Perl bindings are
  stable since xapian-bindings 1.4.16.
* Mon Nov  2 2020 Dirk Stoecker <opensuse@dstoecker.de>
- updated to 1.2.25.2
  see /usr/share/doc/packages/perl-Search-Xapian/Changes
  1.2.25.2  Wed Sep 19 23:58:12 UTC 2018
  [Changes contributed by Olly Betts]
  - Fix to build against Xapian <= 1.4.1 again, broken by changes in
  1.2.25.1.  Reported by Jim Lynch.
  1.2.25.1  Mon Jul  9 03:29:14 UTC 2018
  [Changes contributed by Olly Betts]
  - Skip testcase t/parser.t if we're using xapian-core < 1.2.21 which
  doesn't support character '!' in the start of a range.  Reported by
  melmothx on #xapian.
  - Add compatibility with Xapian git master.
  1.2.25.0  Tue Sep 26 02:06:18 UTC 2017
  [Changes contributed by Olly Betts]
  - Wrap WritableDatabase::commit(), which is the preferred name for
  WritableDatabase::flush().
  - Fix long SEE ALSO lines by putting a newline after each comma in the
  SEE ALSO lists, fixing warnings from man such as:
  <standard input>:109: warning [p 1, 8.0i]: can't break line
  - Backport some improvements to the POD documentation from the
  SWIG-based bindings in xapian-bindings 1.4.x.
  - Avoid perl -W in tests as that seems to break recent versions of
  Test::More.
  - Suppress dummy warning using undef value when building against
  xapian-core 1.4.x.
  1.2.24.0  Fri Sep 16 01:46:36 UTC 2016
  [Changes contributed by Nick Morrott]
  - Fix typo in POD documentation (fixes #730).
  [Changes contributed by Olly Betts]
  - Allow building against xapian-core 1.4.x as well as xapian-core
  1.2.x.
  1.2.23.0  Mon Mar 28 08:44:59 UTC 2016
  [Changes contributed by Olly Betts]
  - makehtmldocs: Fix inter-class links in generated HTML.
  - Fix typo in POD documentation.
  - Update Xapian website and trac links to use https, which is now
  supported, thanks to James Aylett.
  1.2.22.0  Tue Dec 29 06:05:40 UTC 2015
  [Changes contributed by Val Rosca, updated by Andreas Marienborg]
  - Wrap MatchSpy and ValueCountMatchSpy classes
  - Wrap Enquire's add_matchspy and clear_matchspies methods, keeping
  track of references to Perl MatchSpy objects to avoid leaks.
  - t/facets.t
  [Changes contributed by Olly Betts]
  - Fix infinite loop trying to build with CPANPLUS (fixes #692, reported
  by Andreas Vögele).
  - t/termgenerator.t: If a memory leak is detected, report how many
  objects were allocated before and after the test.
  - Allow for "_gitN" tag on snapshots when checking for version
  compatibility with xapian-core.
  - META.yml: Fix specified licence to be a valid name ('perl' instead of
  'perl_5').
  1.2.21.0  Wed May 20 14:34:41 UTC 2015
  [Changes contributed by Olly Betts]
  - Support passing collapse_max argument to Enquire::set_collapse_key().
  Fixes #669, reported by Felix Ostmann.
  - Add missing 'my' to testcases.
  - Add 'use strict' to all testcases.
  - Add a "LICENSE" section to the main POD.
  - META.yml: Specify licence and minimum Perl version.
  - Fix t/symboltest.t to work when built against an installed version
  of xapian-core (broken by changes in 1.2.20.0).
  - Fix "Filehandle STDOUT reopened as M only for input" warning from
  running "perl Makefile.PL".
  1.2.20.0  Wed Mar  4 00:30:08 UTC 2015
  [Changes contributed by Olly Betts]
  - Remove TODO for wrapping MatchAll and MatchNothing - these were added
  in 1.2.13.0.  Reported by Will Crawford.
  - Wrap Xapian::BAD_VALUENO.
  - Fix "make test" to use the Xapian.so we just built, rather than an
  installed version.
  1.2.19.0  Tue Oct 21 00:35:35 UTC 2014
  [Changes contributed by Dmitry Karasik]
  - Fix deliberate leaks in QueryParser::add_valuerangeprocessor() and
  QueryParser::set_stopper() by tracking object ownership properly.
  (ticket#647)
  [Changes contributed by Olly Betts]
  - Fix deliberate leaks in TermGenerator::set_stopper() and Enquire
  methods which allow specifying a Sorter object similarly.
  1.2.18.0  Sun Jun 22 06:39:55 UTC 2014
  [Changes contributed by Olly Betts]
  - README: Add link to "Getting Started with Xapian".
  - Mass whitespace clean-up.
  1.2.17.0  Wed Jan 29 00:00:00 UTC 2014
  - No change except for bumping the version to indicate compatibility
  with Xapian 1.2.17.
  1.2.16.0  Wed Dec  4 00:00:00 UTC 2013
  [Changes contributed by Olly Betts]
  - t/symbol-test/Makefile.PL: Pass $CPPFLAGS and $CXXFLAGS from the
  environment through to the sub-build, fixing symbol-test.t failure
  when built with CPPFLAGS=-D_GLIBCXX_DEBUG.
* Thu Jul 25 2013 llipavsky@suse.de
- update to 1.2.15.0
  - 1.2.15.0  Tue Apr 16 23:43:24 UTC 2013
    [Changes contributed by Olly Betts]
  - Remove superfluous duplicate method wrappers from WritableDatabase
    for methods wrapped in Database parent class.
  - Improve test coverage.
  - Fix minor typo in POD documentation.
  - 1.2.14.0  Thu Mar 14 23:12:38 UTC 2013
    [Changes contributed by Olly Betts]
  - Perl 5.16.1 adds a '.' after "at foo line 123" so adjust regexp in
    testcase t/10query.t to allow an optional '.' there.  (ticket#610)
  - 1.2.13.0  Wed Jan  9 11:19:20 UTC 2013
    [Changes contributed by Adam Sjøgren]
  - Wrap 2 and 3 parameter forms of StringValueRangeProcessor
    constructor so prefixes and suffixes can be specified.
    (ticket#607)
    [Changes contributed by Olly Betts]
  - Wrap the zero argument Query constructor.
  - Add wrappers for Query::MatchAll and Query::MatchNothing.
  - Don't pointlessly reinitialise default std::string parameters to an
    empty string (performance and code size micro-optimisation).
  - 1.2.12.0  Wed Jun 27 12:17:26 UTC 2012
  - No change except for bumping the version to indicate compatibility
    with Xapian 1.2.12.
  - 1.2.11.0  Tue Jun 26 12:13:39 UTC 2012
  - No change except for bumping the version to indicate compatibility
    with Xapian 1.2.11.
  - 1.2.10.0  Wed May  9 10:45:51 UTC 2012
    [Changes contributed by Olly Betts]
  - Wrap Database::close() (was previously only wrapped for
    WritableDatabase).
  - Suppress warnings about "not a known MakeMaker parameter name" in a
    way which also works for newer versions of Perl.
* Sun Apr  1 2012 pascal.bleser@opensuse.org
- update to 1.2.9.0:
  * wrap Document::get_docid() method
  * fix "Use of qw(...) as parentheses is deprecated" warnings in tests with
    Perl 5.14
- changes from 1.2.6.0:
  * wrap new method QueryParser::set_max_wildcard_expansion()
- changes from 1.2.5.0:
  * simpleindex.pl - use 'while' to loop over input lines - 'foreach' reads
    them all in and then loops over them, while reads and processes line by
    line
* Sat Feb 19 2011 pascal.bleser@opensuse.org
- initial version (1.2.4.0)
